EmailProviderConfig class

Configuration for Email/Password authentication

Inheritance

Constructors

EmailProviderConfig({int passwordMinLength = 8, bool requireConfirmPassword = true, String? passwordValidator(String password)?, String? emailValidator(String email)?})
const

Properties

emailValidator String? Function(String email)?
Custom email validator
final
hashCode int
The hash code for this object.
no setterinherited
method AuthMethod
The auth method this config represents
no setteroverride
passwordMinLength int
Minimum password length
final
passwordValidator String? Function(String password)?
Custom password validator
final
requireConfirmPassword bool
Require password confirmation in forms
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateEmail(String email) String?
Default email validation
validatePassword(String password) String?
Default password validation

Operators

operator ==(Object other) bool
The equality operator.
inherited