LayouAppleButton class

Apple sign-in/link button

Inheritance

Constructors

LayouAppleButton({Key? key, required String label, VoidCallback? onPressed, bool isLoading = false, bool enabled = true, ButtonStyle? style, Widget? icon, Widget? loadingIndicator, bool isLinked = false})
const

Properties

enabled bool
Whether the button is enabled
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
Custom icon widget
final
isLinked bool
Whether this provider is already linked (shows check icon)
final
isLoading bool
Whether the button is in loading state
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
Button label
final
loadingIndicator Widget?
Custom loading indicator
final
onPressed VoidCallback?
Called when button is pressed
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style ButtonStyle?
Custom button style
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited